IFRS 17 Module
==============

The IFRS 17 module will provide insurance contract measurement tools.

.. automodule:: actuneo.ifrs17
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* General Measurement Model (GMM)
* Variable Fee Approach (VFA)
* Premium Allocation Approach (PAA)
* Contractual Service Margin (CSM) calculations
* Risk adjustment methodologies
* Discounting techniques

